@@ -223,25 +223,27 @@ class CatBoostMetrics(pl.callbacks.Callback):
 
     @staticmethod
     def log_feature_names(model: "CatboostInterface"):
-        cat_features = {k.value: list(v) for k, v in model.cat_features.items()}
-        text_features = {k.value: list(v) for k, v in model.text_features.items()}
-        non_numeric_features = sum(cat_features.values(), start=[]) + sum(
-            text_features.values(), start=[]
-        )
-        numeric_features = {}
-        for kind in model.FeatureKind:
-            if (features := model.cached_indexed_features_dataframe(kind)) is not None:
-                numeric_features[kind.value] = list(
-                    features.columns.difference(non_numeric_features)
-                )
-        features_description = pd.DataFrame(
-            dict(
-                cat_features=cat_features,
-                text_features=text_features,
-                numeric_features=numeric_features,
-            )
-        ).reset_index()
-        wandb.log(dict(features=wandb.Table(dataframe=features_description)))
+        ...
+        # model.cached_indexed_features_dataframe doesn't have all the features -> wrong description
+        # cat_features = {k.value: list(v) for k, v in model.cat_features.items()}
+        # text_features = {k.value: list(v) for k, v in model.text_features.items()}
+        # non_numeric_features = sum(cat_features.values(), start=[]) + sum(
+        #     text_features.values(), start=[]
+        # )
+        # numeric_features = {}
+        # for kind in model.FeatureKind:
+        #     if (features := model.cached_indexed_features_dataframe(kind)) is not None:
+        #         numeric_features[kind.value] = list(
+        #             features.columns.difference(non_numeric_features)
+        #         )
+        # features_description = pd.DataFrame(
+        #     dict(
+        #         cat_features=cat_features,
+        #         text_features=text_features,
+        #         numeric_features=numeric_features,
+        #     )
+        # ).reset_index()
+        # wandb.log(dict(features=wandb.Table(dataframe=features_description)))
 
     @staticmethod
     def log_single_user_features_dataframe_with_ratings_and_explicit(
